# Security Policy

## Supported Versions

Use this section to tell people about which versions of your project are
currently being supported with security updates.

| Version | Supported          |
| ------- | ------------------ |
| 0.1.0   | :white_check_mark: |

## Reporting a Vulnerability

Please report a vulnerability with a pull request, where you add comments into the 
relevant locations in the code, and detail the vulnerability in the description.
Please seperate this from all functionality changes.
